#[repr(C)]pub struct QrtrClientConnectionGetNodeIdResponse {
pub node_id: u32,
}Fields
node_id: u32Trait Implementations
Sourceimpl Clone for QrtrClientConnectionGetNodeIdResponse
impl Clone for QrtrClientConnectionGetNodeIdResponse
Sourcefn clone(&self) -> QrtrClientConnectionGetNodeIdResponse
fn clone(&self) -> QrtrClientConnectionGetNodeIdResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<QrtrClientConnectionGetNodeIdResponse, D> for QrtrClientConnectionGetNodeIdResponse
impl<D: ResourceDialect> Decode<QrtrClientConnectionGetNodeIdResponse, D> for QrtrClientConnectionGetNodeIdResponse
Sourceimpl<D: ResourceDialect> Encode<QrtrClientConnectionGetNodeIdResponse, D> for &QrtrClientConnectionGetNodeIdResponse
impl<D: ResourceDialect> Encode<QrtrClientConnectionGetNodeIdResponse, D> for &QrtrClientConnectionGetNodeIdResponse
Sourceimpl<D: ResourceDialect, T0: Encode<u32, D>> Encode<QrtrClientConnectionGetNodeIdResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<u32, D>> Encode<QrtrClientConnectionGetNodeIdResponse, D> for (T0,)
Sourceimpl Ord for QrtrClientConnectionGetNodeIdResponse
impl Ord for QrtrClientConnectionGetNodeIdResponse
Sourcefn cmp(&self, other: &QrtrClientConnectionGetNodeIdResponse) -> Ordering
fn cmp(&self, other: &QrtrClientConnectionGetNodeIdResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for QrtrClientConnectionGetNodeIdResponse
impl PartialEq for QrtrClientConnectionGetNodeIdResponse
Sourcefn eq(&self, other: &QrtrClientConnectionGetNodeIdResponse) -> bool
fn eq(&self, other: &QrtrClientConnectionGetNodeIdResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for QrtrClientConnectionGetNodeIdResponse
impl PartialOrd for QrtrClientConnectionGetNodeIdResponse
Sourceimpl TypeMarker for QrtrClientConnectionGetNodeIdResponse
impl TypeMarker for QrtrClientConnectionGetNodeIdResponse
Sourcetype Owned = QrtrClientConnectionGetNodeIdResponse
type Owned = QrtrClientConnectionGetNodeIdResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for QrtrClientConnectionGetNodeIdResponse
impl ValueTypeMarker for QrtrClientConnectionGetNodeIdResponse
Sourcetype Borrowed<'a> = &'a QrtrClientConnectionGetNodeIdResponse
type Borrowed<'a> = &'a QrtrClientConnectionGetNodeIdResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for QrtrClientConnectionGetNodeIdResponse
impl Eq for QrtrClientConnectionGetNodeIdResponse
impl Persistable for QrtrClientConnectionGetNodeIdResponse
impl StructuralPartialEq for QrtrClientConnectionGetNodeIdResponse