pub struct QrtrClientConnectionReadResponse {
pub src_node_id: u32,
pub src_port: u32,
pub data: Vec<u8>,
}Fields
src_node_id: u32src_port: u32data: Vec<u8>Trait Implementations
Sourceimpl Clone for QrtrClientConnectionReadResponse
impl Clone for QrtrClientConnectionReadResponse
Sourcefn clone(&self) -> QrtrClientConnectionReadResponse
fn clone(&self) -> QrtrClientConnectionReadResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<QrtrClientConnectionReadResponse, D> for QrtrClientConnectionReadResponse
impl<D: ResourceDialect> Decode<QrtrClientConnectionReadResponse, D> for QrtrClientConnectionReadResponse
Sourceimpl<D: ResourceDialect> Encode<QrtrClientConnectionReadResponse, D> for &QrtrClientConnectionReadResponse
impl<D: ResourceDialect> Encode<QrtrClientConnectionReadResponse, D> for &QrtrClientConnectionReadResponse
Sourceimpl<D: ResourceDialect, T0: Encode<u32, D>, T1: Encode<u32, D>, T2: Encode<UnboundedVector<u8>, D>> Encode<QrtrClientConnectionReadResponse, D> for (T0, T1, T2)
impl<D: ResourceDialect, T0: Encode<u32, D>, T1: Encode<u32, D>, T2: Encode<UnboundedVector<u8>, D>> Encode<QrtrClientConnectionReadResponse, D> for (T0, T1, T2)
Sourceimpl Ord for QrtrClientConnectionReadResponse
impl Ord for QrtrClientConnectionReadResponse
Sourcefn cmp(&self, other: &QrtrClientConnectionReadResponse) -> Ordering
fn cmp(&self, other: &QrtrClientConnectionReadResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for QrtrClientConnectionReadResponse
impl PartialEq for QrtrClientConnectionReadResponse
Sourcefn eq(&self, other: &QrtrClientConnectionReadResponse) -> bool
fn eq(&self, other: &QrtrClientConnectionReadResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for QrtrClientConnectionReadResponse
impl PartialOrd for QrtrClientConnectionReadResponse
Sourceimpl TypeMarker for QrtrClientConnectionReadResponse
impl TypeMarker for QrtrClientConnectionReadResponse
Sourcetype Owned = QrtrClientConnectionReadResponse
type Owned = QrtrClientConnectionReadResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for QrtrClientConnectionReadResponse
impl ValueTypeMarker for QrtrClientConnectionReadResponse
Sourcetype Borrowed<'a> = &'a QrtrClientConnectionReadResponse
type Borrowed<'a> = &'a QrtrClientConnectionReadResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Eq for QrtrClientConnectionReadResponse
impl Persistable for QrtrClientConnectionReadResponse
impl StructuralPartialEq for QrtrClientConnectionReadResponse