pub struct QrtrTransportChannelReadResponse {
pub data: Vec<u8>,
}Fields
data: Vec<u8>Trait Implementations
Sourceimpl Clone for QrtrTransportChannelReadResponse
impl Clone for QrtrTransportChannelReadResponse
Sourcefn clone(&self) -> QrtrTransportChannelReadResponse
fn clone(&self) -> QrtrTransportChannelReadResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<QrtrTransportChannelReadResponse, D> for QrtrTransportChannelReadResponse
impl<D: ResourceDialect> Decode<QrtrTransportChannelReadResponse, D> for QrtrTransportChannelReadResponse
Sourceimpl<D: ResourceDialect> Encode<QrtrTransportChannelReadResponse, D> for &QrtrTransportChannelReadResponse
impl<D: ResourceDialect> Encode<QrtrTransportChannelReadResponse, D> for &QrtrTransportChannelReadResponse
Sourceimpl<D: ResourceDialect, T0: Encode<UnboundedVector<u8>, D>> Encode<QrtrTransportChannelReadResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<UnboundedVector<u8>, D>> Encode<QrtrTransportChannelReadResponse, D> for (T0,)
Sourceimpl Ord for QrtrTransportChannelReadResponse
impl Ord for QrtrTransportChannelReadResponse
Sourcefn cmp(&self, other: &QrtrTransportChannelReadResponse) -> Ordering
fn cmp(&self, other: &QrtrTransportChannelReadResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for QrtrTransportChannelReadResponse
impl PartialEq for QrtrTransportChannelReadResponse
Sourcefn eq(&self, other: &QrtrTransportChannelReadResponse) -> bool
fn eq(&self, other: &QrtrTransportChannelReadResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for QrtrTransportChannelReadResponse
impl PartialOrd for QrtrTransportChannelReadResponse
Sourceimpl TypeMarker for QrtrTransportChannelReadResponse
impl TypeMarker for QrtrTransportChannelReadResponse
Sourcetype Owned = QrtrTransportChannelReadResponse
type Owned = QrtrTransportChannelReadResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for QrtrTransportChannelReadResponse
impl ValueTypeMarker for QrtrTransportChannelReadResponse
Sourcetype Borrowed<'a> = &'a QrtrTransportChannelReadResponse
type Borrowed<'a> = &'a QrtrTransportChannelReadResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Eq for QrtrTransportChannelReadResponse
impl Persistable for QrtrTransportChannelReadResponse
impl StructuralPartialEq for QrtrTransportChannelReadResponse